@@ -4,11 +4,11 @@ EOL = b"\r\n"
 
 
 def _convert_bytes_to_dict(data: bytes) -> dict:
-    respons = dict()
-    list_values = list()
+    respons = {}
+    list_values = []
     for _ in data.decode("utf-8", errors='ignore').split(EOL.decode()):
         if _ != "":
-            if _.split(": ", 1)[0] in respons.keys():
+            if _.split(": ", 1)[0] in respons:
                 list_values.append(_.split(": ", 1)[1])
                 respons[_.split(": ", 1)[0]] = list_values
                 continue
